import java.io.*;
import java.lang.Math;

public class SpringerProblem
{

    public static void springer(int m, int n, int sx, int sy, int ex, int ey)
    {
	int m2 = m + 4;
	int n2 = n + 4;

	int s = (sy + 1) * m2 + (sx + 1);
	int e = (ey + 1) * m2 + (ex + 1);

	// initialize board and queue

	int pre[]   = new int[m2*n2];
	int queue[] = new int[m2*n2];

	int move[] = {  2 + m2,   2 - m2,   -2 + m2,   -2 - m2,
		      1 + 2*m2, 1 - 2*m2, -1 + 2*m2, -1 - 2*m2};

	for (int i = 0; i < m2*n2; ++i)
	    pre[i] = queue[i] = -1;

	for (int i = 2; i < m+2; ++i)
	    for (int j = 2; j < n+2; ++j)
		pre[j*m2+i] = -2;

	int head = 0;
	int tail = 0;

	// breadth first search
	
	queue[tail++] = s;
	do
	{
	    for (int i = 0; i < 8; ++i)
	    {
		int t = queue[head] + move[i];
		if (pre[t] == -2)
		{
		    pre[t] = queue[head];
		    queue[tail++] = t;
		}
	    }
	    
	} while (++head != tail);

	// print path in reverse order

	if (pre[e] == -2)
	    System.out.println("Fehler: keinen Weg gefunden!");
	else
	{
	    while (e != s)
	    {
		System.out.println("(" + (e%m2-1) + ", " + (e/m2-1) + ")");
		e = pre[e];
	    }
	    System.out.println("(" + (e%m2-1) + ", " + (e/m2-1) + ")");
	}
    }

    public static void main(String[] args) throws Exception
    {
	if (args.length != 6)
	{
 	    System.out.println("Usage: SpringerProblem m n sx sy ex ey");
 	    System.out.println(" m,n   : Size of chess board");
 	    System.out.println(" sx,sy : Starting field.");
 	    System.out.println(" ex,ey : Ending field.");
	    System.exit(1);
	}

	springer(Integer.valueOf(args[0]).intValue(),
                 Integer.valueOf(args[1]).intValue(),
                 Integer.valueOf(args[2]).intValue(),
		 Integer.valueOf(args[3]).intValue(),
		 Integer.valueOf(args[4]).intValue(),
		 Integer.valueOf(args[5]).intValue());
    }
}
